@@ -10,9 +10,7 @@
 namespace SebastianBergmann\Complexity;
 
 use function file_get_contents;
-use PhpParser\Lexer;
 use PhpParser\NodeTraverser;
-use PhpParser\Parser;
 use PhpParser\ParserFactory;
 use PHPUnit\Framework\Attributes\CoversClass;
 use PHPUnit\Framework\Attributes\Small;
@@ -24,9 +22,13 @@ final class CyclomaticComplexityCalculatingVisitorTest extends TestCase
 {
     public function testCalculatesCyclomaticComplexityForAbstractSyntaxTree(): void
     {
-        $nodes = $this->parser()->parse(
-            file_get_contents(__DIR__ . '/../_fixture/example_function.php'),
-        );
+        $source = file_get_contents(__DIR__ . '/../_fixture/example_function.php');
+
+        $this->assertIsString($source);
+
+        $nodes = (new ParserFactory)->createForHostVersion()->parse($source);
+
+        $this->assertNotNull($nodes);
 
         $traverser = new NodeTraverser;
 
@@ -37,11 +39,6 @@ final class CyclomaticComplexityCalculatingVisitorTest extends TestCase
         /* @noinspection UnusedFunctionResultInspection */
         $traverser->traverse($nodes);
 
-        $this->assertSame(14, $visitor->cyclomaticComplexity());
-    }
-
-    private function parser(): Parser
-    {
-        return (new ParserFactory)->create(ParserFactory::PREFER_PHP7, new Lexer);
+        $this->assertSame(16, $visitor->cyclomaticComplexity());
     }
 }
